Crate synapto_interface

Crate synapto_interface 

Modules

cognitive_output_audio
cognitive_output_text
llm
peer_input_audio
peer_input_text
speech_to_text
storage
sync
Instrumented synchronization primitives and re-exports of tokio::sync.
types
Core data types used across the interface and core engine.

Macros

register_channel_name
Registers a semantic name for a message type to be used in telemetry pulses.

Structs

EmptyPluginConfig

Traits

AudioInputPlugin
AudioOutputPlugin
AudioRecorderPlugin
CallPlugin
CameraPlugin
ChatPlugin
DiarizationPlugin
DocumentsPlugin
GuiPlugin
InteractionObserver
Plugin
PluginRegistry
RetrospectiveConsolidationPlugin
RolloutController
STTPlugin
TTSPlugin