Module credentials

Module credentials 

Structs

CredentialsBuilder
Builder used by credential providers to register their typed resolvers.
CredentialsHandle
Type-erased registry container for runtime credential resolution.

Traits

CredentialTarget
Domain marker trait for credential target descriptors.
PluggableCredentialsProvider
Factory trait for pluggable credential providers initialized by Synapto.
ProvideApiKey
Capability trait for API keys (e.g. Speechmatics, OpenAI, Anthropic, ElevenLabs).
ProvideBasicAuth
Capability trait for basic authentication (username and secret password).
ProvideBearerToken
Capability trait for scoped bearer tokens (e.g. Google Cloud, AWS STS, Azure AD, OAuth2).