pub enum DocumentIngestionPolicy {
Store,
StoreAndParse,
}Variants
Store
Save the raw document only, do not attempt to parse or extract text.
StoreAndParse
Save the raw document and run active parsers (e.g. PDF parser) to extract UTF-8 text.