pub struct DocumentRegistrationRequest {
pub original_filename: String,
pub mime_type: String,
pub data: Vec<u8>,
pub policy: DocumentIngestionPolicy,
}Fields
original_filename: Stringmime_type: Stringdata: Vec<u8>policy: DocumentIngestionPolicyTrait Implementations
Sourceimpl Clone for DocumentRegistrationRequest
impl Clone for DocumentRegistrationRequest
Sourcefn clone(&self) -> DocumentRegistrationRequest
fn clone(&self) -> DocumentRegistrationRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DocumentRegistrationRequest
impl Debug for DocumentRegistrationRequest
Sourceimpl<'de> Deserialize<'de> for DocumentRegistrationRequest
impl<'de> Deserialize<'de> for DocumentRegistrationRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DocumentRegistrationRequest
Sourceimpl JsonSchema for DocumentRegistrationRequest
impl JsonSchema for DocumentRegistrationRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for DocumentRegistrationRequest