pub struct CognitiveSpoken(pub String);Tuple Fields
0: StringTrait Implementations
Sourceimpl Clone for CognitiveSpoken
impl Clone for CognitiveSpoken
Sourcefn clone(&self) -> CognitiveSpoken
fn clone(&self) -> CognitiveSpoken
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CognitiveSpoken
impl Debug for CognitiveSpoken
Sourceimpl<'de> Deserialize<'de> for CognitiveSpoken
impl<'de> Deserialize<'de> for CognitiveSpoken
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CognitiveSpoken
Sourceimpl JsonSchema for CognitiveSpoken
impl JsonSchema for CognitiveSpoken
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CognitiveSpoken
impl PartialEq for CognitiveSpoken
Sourceimpl Serialize for CognitiveSpoken
impl Serialize for CognitiveSpoken
impl StructuralPartialEq for CognitiveSpoken