pub struct CognitiveWritten {
pub target_channel: MessageChannel,
pub text: String,
}Fields
target_channel: MessageChanneltext: StringTrait Implementations
Sourceimpl Clone for CognitiveWritten
impl Clone for CognitiveWritten
Sourcefn clone(&self) -> CognitiveWritten
fn clone(&self) -> CognitiveWritten
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CognitiveWritten
impl Debug for CognitiveWritten
Sourceimpl<'de> Deserialize<'de> for CognitiveWritten
impl<'de> Deserialize<'de> for CognitiveWritten
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CognitiveWritten
Sourceimpl JsonSchema for CognitiveWritten
impl JsonSchema for CognitiveWritten
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CognitiveWritten
impl PartialEq for CognitiveWritten
Sourceimpl Serialize for CognitiveWritten
impl Serialize for CognitiveWritten
impl StructuralPartialEq for CognitiveWritten