pub struct ObservedInteraction {
pub timestamp: Timestamp,
pub user_messages: Vec<PeerInput>,
pub ai_spoken: Option<AiSpoken>,
pub ai_written: Option<AiWritten>,
pub ai_reasoning: Option<CognitiveReasoning>,
}Fields
timestamp: Timestampuser_messages: Vec<PeerInput>ai_spoken: Option<AiSpoken>ai_written: Option<AiWritten>ai_reasoning: Option<CognitiveReasoning>Trait Implementations
Sourceimpl Clone for ObservedInteraction
impl Clone for ObservedInteraction
Sourcefn clone(&self) -> ObservedInteraction
fn clone(&self) -> ObservedInteraction
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ObservedInteraction
impl Debug for ObservedInteraction
Sourceimpl<'de> Deserialize<'de> for ObservedInteraction
impl<'de> Deserialize<'de> for ObservedInteraction
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ObservedInteraction
Sourceimpl JsonSchema for ObservedInteraction
impl JsonSchema for ObservedInteraction
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ObservedInteraction
impl PartialEq for ObservedInteraction
Sourceimpl Serialize for ObservedInteraction
impl Serialize for ObservedInteraction
impl StructuralPartialEq for ObservedInteraction