Core data types used across the interface and core engine.
Re-exports
pub use genai;
Structs
- LlmExecutor
- Opaque handle to the LLM execution runtime.
- Model
Config - RawLlm
Options
Core data types used across the interface and core engine.
pub use genai;