pub struct ModelConfig {
pub model: String,
pub reasoning_effort: ReasoningEffort,
}Fields
model: Stringreasoning_effort: ReasoningEffortTrait Implementations
Sourceimpl Clone for ModelConfig
impl Clone for ModelConfig
Sourcefn clone(&self) -> ModelConfig
fn clone(&self) -> ModelConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModelConfig
impl Debug for ModelConfig
Sourceimpl<'de> Deserialize<'de> for ModelConfig
impl<'de> Deserialize<'de> for ModelConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ModelConfig
Sourceimpl JsonSchema for ModelConfig
impl JsonSchema for ModelConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ModelConfig
impl PartialEq for ModelConfig
Sourceimpl Serialize for ModelConfig
impl Serialize for ModelConfig
impl StructuralPartialEq for ModelConfig