pub struct Secret<T>(/* private fields */);Expand description
A wrapper that redacts its contents in Debug logs and Serialization (UI/API), requiring explicit method calls to access the underlying value.
Implementations
Sourceimpl<T> Secret<T>
impl<T> Secret<T>
Sourcepub fn expose_secret(&self) -> &T
pub fn expose_secret(&self) -> &T
Explicitly exposes the secret by reference.
Sourcepub fn expose_owned_secret(self) -> T
pub fn expose_owned_secret(self) -> T
Consumes the wrapper and returns the raw secret.
pub fn into_secret<U>(self) -> Secret<U>where
T: Into<U>,