Module speech_to_text

Module speech_to_text 

Structs

CosineSimilarity
PeerInputAudioIndexed
A raw audio chunk bundled with its sequence sequence index.
SpeakerId
A unique identifier for a speaker.
SpeakerSegment
SpeechDetected
Signal indicating that speech activity has been detected.
SpeechTranscript
A transcribed segment of speech.
Word
Represents a single word within a transcription.
WordOverlap

Enums

InputVoiceAudio
Represents an audio chunk with its associated voice activity status.
InternalSpeaker

Traits

DiarizationPlugin
STTPlugin
TTSPlugin

Functions

calculate_chunk_indices
Calculates the discrete audio chunk indices for a given continuous time range.

Type Aliases

SpeakerHeuristicCallback