pub struct StorageRegistry { /* private fields */ }Implementations
Sourceimpl StorageRegistry
impl StorageRegistry
Sourcepub async fn get_or_init<T: StorageProviderPool, F, Fut, E>(
&self,
init: F,
) -> Result<Arc<T>, E>
pub async fn get_or_init<T: StorageProviderPool, F, Fut, E>( &self, init: F, ) -> Result<Arc<T>, E>
Lazily initializes a global shared resource. If the resource already exists, it is returned immediately. This allows multiple plugins to safely share a single connection pool without requiring manual initialization in main.rs.