TypeChannelName

Trait TypeChannelName 

pub trait TypeChannelName {
    const CHANNEL_NAME: &'static str;
}
Trait used to provide a semantic name for a type in telemetry pulses.

This is used by the register_channel_name! macro to associate a friendly string with a specific message type.

Required Associated Constants

const CHANNEL_NAME: &'static str

The semantic name of the channel/message type.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl TypeChannelName for AddDocumentRequest

Available on debug-assertions enabled only.
Source

const CHANNEL_NAME: &'static str = "add_document_request"

Source

impl TypeChannelName for CameraInputFrame

Available on debug-assertions enabled only.
Source

const CHANNEL_NAME: &'static str = "camera_input_frame"

Source

impl TypeChannelName for CognitiveOutputAudio

Available on debug-assertions enabled only.
Source

const CHANNEL_NAME: &'static str = "cognitive_output_audio"

Source

impl TypeChannelName for CognitiveOutputSpeech

Available on debug-assertions enabled only.
Source

const CHANNEL_NAME: &'static str = "ai_output_speech"

Source

impl TypeChannelName for CognitiveOutputText

Available on debug-assertions enabled only.
Source

const CHANNEL_NAME: &'static str = "cognitive_output_text"

Source

impl TypeChannelName for CognitiveStateUpdate

Available on debug-assertions enabled only.
Source

const CHANNEL_NAME: &'static str = "cognitive_state"

Source

impl TypeChannelName for DocumentId

Available on debug-assertions enabled only.
Source

const CHANNEL_NAME: &'static str = "document_id"

Source

impl TypeChannelName for Enveloped<CognitiveOutputText>

Available on debug-assertions enabled only.
Source

const CHANNEL_NAME: &'static str = "cognitive_output_text_enveloped"

Source

impl TypeChannelName for Enveloped<CognitiveStateUpdate>

Available on debug-assertions enabled only.
Source

const CHANNEL_NAME: &'static str = "cognitive_state_enveloped"

Source

impl TypeChannelName for Enveloped<PeerInputText>

Available on debug-assertions enabled only.
Source

const CHANNEL_NAME: &'static str = "peer_input_text_enveloped"

Source

impl TypeChannelName for InputVoiceAudio

Available on debug-assertions enabled only.
Source

const CHANNEL_NAME: &'static str = "input_voice_audio"

Source

impl TypeChannelName for NotClearInteraction

Available on debug-assertions enabled only.
Source

const CHANNEL_NAME: &'static str = "not_clear_interaction"

Source

impl TypeChannelName for ObservedInteraction

Available on debug-assertions enabled only.
Source

const CHANNEL_NAME: &'static str = "observed_interaction"

Source

impl TypeChannelName for PeerInputAudio

Available on debug-assertions enabled only.
Source

const CHANNEL_NAME: &'static str = "peer_input_audio"

Source

impl TypeChannelName for PeerInputSpeech

Available on debug-assertions enabled only.
Source

const CHANNEL_NAME: &'static str = "peer_input_speech"

Source

impl TypeChannelName for PeerInputText

Available on debug-assertions enabled only.
Source

const CHANNEL_NAME: &'static str = "peer_input_text"

Source

impl TypeChannelName for ReadDocumentRequest

Available on debug-assertions enabled only.
Source

const CHANNEL_NAME: &'static str = "read_document_request"

Source

impl TypeChannelName for ReadUrlRequest

Available on debug-assertions enabled only.
Source

const CHANNEL_NAME: &'static str = "read_url_request"

Source

impl TypeChannelName for SpeakerSegment

Available on debug-assertions enabled only.
Source

const CHANNEL_NAME: &'static str = "speaker_segment"

Source

impl TypeChannelName for SpeechTranscript

Available on debug-assertions enabled only.
Source

const CHANNEL_NAME: &'static str = "speech_transcript"

Source

impl TypeChannelName for Timestamp

Available on debug-assertions enabled only.
Source

const CHANNEL_NAME: &'static str = "timestamp"

Source

impl TypeChannelName for ToolCallId

Available on debug-assertions enabled only.
Source

const CHANNEL_NAME: &'static str = "tool_call_id"