pub struct NotClearInteraction {
pub timestamp: Timestamp,
pub user_messages: Vec<PeerInput>,
pub ai_spoken: Option<AiSpoken>,
pub ai_written: Option<AiWritten>,
}Fields
timestamp: Timestampuser_messages: Vec<PeerInput>ai_spoken: Option<AiSpoken>ai_written: Option<AiWritten>Trait Implementations
Sourceimpl Clone for NotClearInteraction
impl Clone for NotClearInteraction
Sourcefn clone(&self) -> NotClearInteraction
fn clone(&self) -> NotClearInteraction
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NotClearInteraction
impl Debug for NotClearInteraction
Sourceimpl<'de> Deserialize<'de> for NotClearInteraction
impl<'de> Deserialize<'de> for NotClearInteraction
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for NotClearInteraction
Sourceimpl JsonSchema for NotClearInteraction
impl JsonSchema for NotClearInteraction
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for NotClearInteraction
impl PartialEq for NotClearInteraction
Sourcefn eq(&self, other: &NotClearInteraction) -> bool
fn eq(&self, other: &NotClearInteraction) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for NotClearInteraction
impl Serialize for NotClearInteraction
impl StructuralPartialEq for NotClearInteraction
Sourceimpl TypeChannelName for NotClearInteraction
Available on debug-assertions enabled only.
impl TypeChannelName for NotClearInteraction
Available on debug-assertions enabled only.
Sourceconst CHANNEL_NAME: &'static str = "not_clear_interaction"
const CHANNEL_NAME: &'static str = "not_clear_interaction"
The semantic name of the channel/message type.