Modules
- cognitive_
output_ audio - cognitive_
output_ text - llm
- peer_
input_ audio - peer_
input_ text - speech_
to_ text - storage
- sync
- Instrumented synchronization primitives and re-exports of
tokio::sync. - types
- Core data types used across the interface and core engine.
Macros
- register_
channel_ name - Registers a semantic name for a message type to be used in telemetry pulses.