Structs
Traits
- Collection
Store - For data that is just a list of items with no natural key (e.g., Behavioral Insights) The database automatically handles row creation and ID generation.
- File
Store - Trait for storing, retrieving, and deleting raw binary files.
- KeyValue
Store - For storing and retrieving items by a unique string ID.
- Storage
Config Resolver - Storage
Connection - The entry point for a generic storage adapter. It guarantees that plugins can seamlessly initialize their underlying connection using the shared StorageRegistry without requiring manual setup in main.rs.
- Storage
Provider Pool - A marker trait for safe DB connection pooling
- Vector
Store