Modules
- broadcast
- A multi-producer, multi-consumer broadcast queue. Each sent value is seen by all consumers.
- futures
- Named future types.
- mpsc
- A multi-producer, single-consumer queue for sending values between asynchronous tasks.
- oneshot
- A one-shot channel is used for sending a single message between
asynchronous tasks. The
channelfunction is used to create aSenderandReceiverhandle pair that form the channel. - watch
- A multi-producer, multi-consumer channel that only retains the last sent value.
Structs
- Acquire
Error - Error returned from the
Semaphore::acquirefunction. - Barrier
- A barrier enables multiple tasks to synchronize the beginning of some computation.
- Barrier
Wait Result - A
BarrierWaitResultis returned bywaitwhen all tasks in theBarrierhave rendezvoused. - Mapped
Mutex Guard - A handle to a held
Mutexthat has had a function applied to it viaMutexGuard::map. - Mutex
- An asynchronous
Mutex-like type. - Mutex
Guard - A handle to a held
Mutex. The guard can be held across any.awaitpoint as it isSend. - Notify
- Notifies a single task to wake up.
- Once
Cell - A thread-safe cell that can be written to only once.
- Owned
Mapped Mutex Guard - A owned handle to a held
Mutexthat has had a function applied to it viaOwnedMutexGuard::map. - Owned
Mutex Guard - An owned handle to a held
Mutex. - Owned
RwLock Mapped Write Guard - Owned RAII structure used to release the exclusive write access of a lock when dropped.
- Owned
RwLock Read Guard - Owned RAII structure used to release the shared read access of a lock when dropped.
- Owned
RwLock Write Guard - Owned RAII structure used to release the exclusive write access of a lock when dropped.
- Owned
Semaphore Permit - An owned permit from the semaphore.
- RwLock
- An asynchronous reader-writer lock.
- RwLock
Mapped Write Guard - RAII structure used to release the exclusive write access of a lock when dropped.
- RwLock
Read Guard - RAII structure used to release the shared read access of a lock when dropped.
- RwLock
Write Guard - RAII structure used to release the exclusive write access of a lock when dropped.
- Semaphore
- Counting semaphore performing asynchronous permit acquisition.
- Semaphore
Permit - A permit from the semaphore.
- SetOnce
- A thread-safe cell that can be written to only once.
- SetOnce
Error - Error that can be returned from
SetOnce::set. - TryLock
Error - Error returned from the
Mutex::try_lock,RwLock::try_readandRwLock::try_writefunctions.
Enums
- SetError
- Errors that can be returned from
OnceCell::set. - TryAcquire
Error - Error returned from the
Semaphore::try_acquirefunction.